@@ -28,6 +28,7 @@ class Samples:
                  use_band_dict=None,
                  max_allow_x=1e13,
                  max_allow_y=1e13,
+                 line_limit=None,
                  **kwargs):
 
         """
@@ -80,16 +81,17 @@ class Samples:
 
         # either of label name or csv file is provided without the other
         if (csv_file is None) and (label_colname is None):
-            pass  # warnings.warn("Samples class initiated without data file or label")
+            warnings.warn("Samples class initiated without data file or label")
 
         # label name or csv file are provided
         elif (label_colname is not None) and (csv_file is not None):
 
-            temp = Handler(filename=csv_file).read_from_csv(return_dicts=True)
+            temp = Handler(filename=csv_file).read_from_csv(return_dicts=True,
+                                                            line_limit=line_limit)
             header = list(temp[0])
 
             # label name doesn't match
-            if not any(label_colname in s for s in header):
+            if label_colname not in header:
                 loc = header.index(label_colname)
             else:
                 raise ValueError("Label name mismatch.\nAvailable names: " + ', '.join(header))
@@ -109,8 +111,8 @@ class Samples:
                 self.y_name = [use_band_dict[b] for b in self.y_name]
 
         elif (label_colname is None) and (csv_file is not None):
-
-            temp = Handler(filename=csv_file).read_from_csv()
+            temp = Handler(filename=csv_file).read_from_csv(return_dicts=True,
+                                                            line_limit=line_limit)
 
             # read from data dictionary
             self.x_name = list(temp[0])
